@@ -11,14 +11,14 @@
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_abb_name(name)
+#' stata |> join_abb_name(name)
 join_abb_name <- function(.data, .name) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$abb)
+  stata <- stata |> dplyr::select(.data$name, .data$abb)
   by_char <- 'name'
   names(by_char) <- rlang::as_name(rlang::enquo(.name))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -35,14 +35,14 @@ join_abb_name <- function(.data, .name) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_fips_name(name)
+#' stata |> join_fips_name(name)
 join_fips_name <- function(.data, .name) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$fips)
+  stata <- stata |> dplyr::select(.data$name, .data$fips)
   by_char <- 'name'
   names(by_char) <- rlang::as_name(rlang::enquo(.name))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join ANSI by Name
@@ -58,14 +58,14 @@ join_fips_name <- function(.data, .name) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_ansi_name(name)
+#' stata |> join_ansi_name(name)
 join_ansi_name <- function(.data, .name) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$ansi)
+  stata <- stata |> dplyr::select(.data$name, .data$ansi)
   by_char <- 'name'
   names(by_char) <- rlang::as_name(rlang::enquo(.name))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join Name by Abb
@@ -81,14 +81,14 @@ join_ansi_name <- function(.data, .name) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_name_abb(abb)
+#' stata |> join_name_abb(abb)
 join_name_abb <- function(.data, .abb) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$abb)
+  stata <- stata |> dplyr::select(.data$name, .data$abb)
   by_char <- 'abb'
   names(by_char) <- rlang::as_name(rlang::enquo(.abb))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -105,14 +105,14 @@ join_name_abb <- function(.data, .abb) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_fips_abb(abb)
+#' stata |> join_fips_abb(abb)
 join_fips_abb <- function(.data, .abb) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$fips, .data$abb)
+  stata <- stata |> dplyr::select(.data$fips, .data$abb)
   by_char <- 'abb'
   names(by_char) <- rlang::as_name(rlang::enquo(.abb))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join ANSI by Abb
@@ -128,14 +128,14 @@ join_fips_abb <- function(.data, .abb) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_ansi_abb(abb)
+#' stata |> join_ansi_abb(abb)
 join_ansi_abb <- function(.data, .abb) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$ansi, .data$abb)
+  stata <- stata |> dplyr::select(.data$ansi, .data$abb)
   by_char <- 'abb'
   names(by_char) <- rlang::as_name(rlang::enquo(.abb))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -152,14 +152,14 @@ join_ansi_abb <- function(.data, .abb) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_abb_ansi(ansi)
+#' stata |> join_abb_ansi(ansi)
 join_abb_ansi <- function(.data, .ansi) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$ansi, .data$abb)
+  stata <- stata |> dplyr::select(.data$ansi, .data$abb)
   by_char <- 'ansi'
   names(by_char) <- rlang::as_name(rlang::enquo(.ansi))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join Name by ANSI
@@ -175,14 +175,14 @@ join_abb_ansi <- function(.data, .ansi) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_name_ansi(name)
+#' stata |> join_name_ansi(name)
 join_name_ansi <- function(.data, .ansi) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$ansi)
+  stata <- stata |> dplyr::select(.data$name, .data$ansi)
   by_char <- 'ansi'
   names(by_char) <- rlang::as_name(rlang::enquo(.ansi))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join FIPS by ANSI
@@ -198,14 +198,14 @@ join_name_ansi <- function(.data, .ansi) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_fips_ansi(ansi)
+#' stata |> join_fips_ansi(ansi)
 join_fips_ansi <- function(.data, .ansi) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$fips, .data$ansi)
+  stata <- stata |> dplyr::select(.data$fips, .data$ansi)
   by_char <- 'ansi'
   names(by_char) <- rlang::as_name(rlang::enquo(.ansi))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -222,14 +222,14 @@ join_fips_ansi <- function(.data, .ansi) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_ansi_fips(fips)
+#' stata |> join_ansi_fips(fips)
 join_ansi_fips <- function(.data, .fips) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$fips, .data$ansi)
+  stata <- stata |> dplyr::select(.data$fips, .data$ansi)
   by_char <- 'fips'
   names(by_char) <- rlang::as_name(rlang::enquo(.fips))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 #' Join Abb by FIPS
@@ -245,14 +245,14 @@ join_ansi_fips <- function(.data, .fips) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_abb_fips(fips)
+#' stata |> join_abb_fips(fips)
 join_abb_fips <- function(.data, .fips) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$fips, .data$abb)
+  stata <- stata |> dplyr::select(.data$fips, .data$abb)
   by_char <- 'fips'
   names(by_char) <- rlang::as_name(rlang::enquo(.fips))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -269,14 +269,14 @@ join_abb_fips <- function(.data, .fips) {
 #' @concept join
 #' @examples
 #' data('stata')
-#' stata %>% join_name_fips(fips)
+#' stata |> join_name_fips(fips)
 join_name_fips <- function(.data, .fips) {
   stata <- get('stata')
-  stata <- stata %>% dplyr::select(.data$name, .data$fips)
+  stata <- stata |> dplyr::select(.data$name, .data$fips)
   by_char <- 'fips'
   names(by_char) <- rlang::as_name(rlang::enquo(.fips))
 
-  .data %>% dplyr::left_join(stata, by = by_char)
+  .data |> dplyr::left_join(stata, by = by_char)
 }
 
 
@@ -293,12 +293,12 @@ join_name_fips <- function(.data, .fips) {
 # #' @concept join
 # #' @examples
 # #' data('stata')
-# #' stata %>% join_new_old(old)
+# #' stata |> join_new_old(old)
 # join_new_old <- function(.data, .old) {
 #   stata <- get('stata')
-#   stata <- stata %>% dplyr::select(.data$new, .data$old)
+#   stata <- stata |> dplyr::select(.data$new, .data$old)
 #   by_char <- 'old'
 #   names(by_char) <- rlang::as_name(rlang::enquo(.old))
 #
-#   .data %>% dplyr::left_join(stata, by = by_char)
+#   .data |> dplyr::left_join(stata, by = by_char)
 # }
